==> krename-2.8.3.tar.bz2: krename-2.8.3/krename/wizard.cpp <==
/***************************************************************************
                          wizard.cpp  -  description
                             -------------------
    begin                : Die Mai 15 15:34:19 CEST 2001
    copyright            : (C) 2001 by Dominik Seichter
    email                : domseichter@web.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

// Own includes
#include "wizard.h"
#include "krenameimpl.h"

// KDE includes
#include <kapplication.h>
#include <kiconloader.h>
#include <klocale.h>
#include <kmenubar.h>
#include <kmessagebox.h>
#include <kstartupinfo.h>

// Qt includes
#include <qlabel.h>
#include <qlayout.h>

wizard::wizard( KRenameImpl* impl, QRect r, QWidget* parent,  const char* name, bool modal, WFlags fl )
    : KWizard( parent, name, modal, fl )
{
    setIcon( BarIcon( "krename" ) );
    setTitleFont( QFont( "Helvetica", 0 ) );

    menuBar = new KMenuBar(this);

    if( impl ) {
        krename = impl;
        connect( krename, SIGNAL( pageDone( QWidget*, const QString & ) ), this, SLOT( slotAddPage( QWidget*, const QString & ) ) );
        krename->changeParent( this, menuBar, this->finishButton(), r );
    } else {
        krename = new KRenameImpl( this, menuBar, this->finishButton() );
        connect( krename, SIGNAL( pageDone( QWidget*, const QString & ) ), this, SLOT( slotAddPage( QWidget*, const QString & ) ) );
    }
    
    connect( krename, SIGNAL( showPage( int ) ), this, SLOT( slotShowPage( int ) ) );
    connect( krename, SIGNAL( enableFinish( bool ) ), this, SLOT( slotEnableFinish( bool ) ) );
    if( !impl )
        krename->setup();
    
    // Tell KStartupInfo that KRename has been loaded completly
    KStartupInfoId id;
    id.initId( kapp->startupId() );
    KStartupInfo::sendFinish( id );
}

wizard::~wizard()
{
}

void wizard::slotAddPage( QWidget* page, const QString & title )
{
    QWidget* w = new QWidget( this );
    QVBoxLayout* layout = new QVBoxLayout( w, 6 );
   
    QHBoxLayout * l = new QHBoxLayout( 6 );
    l->addWidget( new QLabel( QString( title ).remove( title.find( "&" ), 1 ), w ) );
    l->addStrut( 12 );

    QFrame* hbar0 = new QFrame( w, 0 );
    QFrame* hbar1 = new QFrame( w, "<hr>", 0 );
    hbar1->setFrameStyle( QFrame::Sunken + QFrame::HLine );

    page->reparent( w, QPoint( 0, 0 ) );

    layout->addWidget( hbar0 );
    layout->addLayout( l, 0 );
    layout->addWidget( hbar1 );
    layout->addWidget( page );    

    addPage( w, title );
}

void wizard::slotShowPage( int page )
{
    showPage( this->page( page - 1 ) );
}

void wizard::slotEnableFinish( bool b )
{
    setFinishEnabled( page( pageCount() - 1), b );
}

void wizard::closeEvent( QCloseEvent* e )
{
    if( krename->askOnExit() )
        if( KMessageBox::questionYesNo( this, i18n("Do you really want to quit Krename ?") ) == KMessageBox::Yes ) {
            e->accept();
        } else
            e->ignore();
    else {
        e->accept();
    }
}

void wizard::accept()
{ /* Do nothing */ }

void wizard::reject()
{
    this->close();
}

==> krename-3.0.7.tar.bz2: krename-3.0.7/krename/wizard.cpp <==
/***************************************************************************
                          wizard.cpp  -  description
                             -------------------
    begin                : Die Mai 15 15:34:19 CEST 2001
    copyright            : (C) 2001 by Dominik Seichter
    email                : domseichter@web.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

// Own includes
#include "wizard.h"
#include "krenameimpl.h"

// KDE includes
#include <kapplication.h>
#include <kiconloader.h>
#include <klocale.h>
#include <kmenubar.h>
#include <kmessagebox.h>
#include <kstartupinfo.h>

// Qt includes
#include <qlabel.h>
#include <qlayout.h>
#include <qpushbutton.h>
#include <qsizepolicy.h>
#include <qvbox.h>

wizard::wizard( KRenameImpl* impl, QRect r, QWidget* parent,  const char* name )
    : KWizard( parent, name )
{
    setIcon( BarIcon( "krename" ) );
    menuBar = new KMenuBar(this);

    if( impl ) {
        krename = impl;
        connect( krename, SIGNAL( pageDone( QWidget*, const QString & ) ), this, SLOT( slotAddPage( QWidget*, const QString & ) ) );
        krename->changeParent( this, menuBar, this->finishButton(), r );
    } else {
        krename = new KRenameImpl( this, menuBar, this->finishButton() );
        connect( krename, SIGNAL( pageDone( QWidget*, const QString & ) ), this, SLOT( slotAddPage( QWidget*, const QString & ) ) );
    }
    
    connect( krename, SIGNAL( showPage( int ) ), this, SLOT( slotShowPage( int ) ) );
    connect( krename, SIGNAL( enableFinish( bool ) ), this, SLOT( slotEnableFinish( bool ) ) );
    if( !impl )
        krename->setup( true );
    
    // Tell KStartupInfo that KRename has been loaded completly
    KStartupInfoId id;
    id.initId( kapp->startupId() );
    KStartupInfo::sendFinish( id );
    
    // Disable ESC key
    cancelButton()->setAccel( QKeySequence() );
}

wizard::~wizard()
{
}

void wizard::slotAddPage( QWidget* page, const QString & title )
{
    // exclude page 3 from wizard
    if( krename->title( 2 ) == title )
    {
        page->hide();
        return;
    }

    QString t = title + i18n(" - Step %1 of %2").arg( pageCount()+1 ).arg( 3 );
        
    QVBox* layout = new QVBox( this );
   
    new QLabel( QString( t ).remove( title.find( "&" ), 1 ), layout );

    QFrame* hbar1 = new QFrame( layout, "<hr>", 0 );
    hbar1->setFrameStyle( QFrame::Sunken + QFrame::HLine );

    page->reparent( layout, QPoint( 0, 0 ) );
    addPage( layout, t );
    setHelpEnabled( layout, false );
}

void wizard::slotShowPage( int page )
{
    showPage( this->page( page - 1 ) );
}

void wizard::slotEnableFinish( bool b )
{
    setFinishEnabled( page( pageCount() - 1), b );
}

void wizard::accept()
{
/** do nothing */
}
